Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/atlus/__init__.py | (no class) | 4 | 0 | 0 | 0 | 0 | 100%
src/atlus/atlus.py | (no class) | 162 | 8 | 0 | 63 | 17 | 88%
src/atlus/objects.py | Address | 0 | 0 | 0 | 0 | 0 | 100%
src/atlus/objects.py | (no class) | 9 | 0 | 0 | 0 | 0 | 100%
src/atlus/resources.py | (no class) | 24 | 0 | 0 | 2 | 0 | 100%
Total |  | 199 | 8 | 0 | 65 | 17 | 90%

No items found using the specified filter.